summaryrefslogtreecommitdiffstats
path: root/kmymoney2/plugins/kmymoneyplugin.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/plugins/kmymoneyplugin.h')
-rw-r--r--kmymoney2/plugins/kmymoneyplugin.h33
1 files changed, 17 insertions, 16 deletions
diff --git a/kmymoney2/plugins/kmymoneyplugin.h b/kmymoney2/plugins/kmymoneyplugin.h
index 2978fde..f5cdac6 100644
--- a/kmymoney2/plugins/kmymoneyplugin.h
+++ b/kmymoney2/plugins/kmymoneyplugin.h
@@ -25,7 +25,7 @@
// ----------------------------------------------------------------------------
// QT Includes
-#include <qobject.h>
+#include <tqobject.h>
// ----------------------------------------------------------------------------
// KDE Includes
@@ -56,19 +56,20 @@ namespace KMyMoneyPlugin {
* http://developer.kde.org/documentation/tutorials/developing-a-plugin-structure/index.html
*
*/
- class KMYMONEY_EXPORT Plugin : public QObject, public KXMLGUIClient
+ class KMYMONEY_EXPORT Plugin : public TQObject, public KXMLGUIClient
{
Q_OBJECT
+ TQ_OBJECT
public:
- Plugin(QObject* parent, const char* name);
+ Plugin(TQObject* tqparent, const char* name);
virtual ~Plugin();
protected:
/** See KMyMoney2App::action() for a description */
- KAction* action(const QString& name) const;
+ KAction* action(const TQString& name) const;
/** See KMyMoney2App::toggleAction() for a description */
- KToggleAction* toggleAction(const QString& name) const;
+ KToggleAction* toggleAction(const TQString& name) const;
// define interface classes here. The interface classes provide a mechanism
// for the plugin to interact with KMyMoney
@@ -97,7 +98,7 @@ namespace KMyMoneyPlugin {
OnlinePlugin() {}
virtual ~OnlinePlugin() {}
- virtual void protocols(QStringList& protocolList) const = 0;
+ virtual void protocols(TQStringList& protocolList) const = 0;
/**
* This method returns a pointer to a widget representing an additional
@@ -112,7 +113,7 @@ namespace KMyMoneyPlugin {
* can access the widgets created after the call to storeConfigParameters()
* happened.
*/
- virtual QWidget* accountConfigTab(const MyMoneyAccount& account, QString& tabName) = 0;
+ virtual TQWidget* accountConfigTab(const MyMoneyAccount& account, TQString& tabName) = 0;
/**
* This method is called by the framework whenever it is time to store
@@ -167,18 +168,18 @@ namespace KMyMoneyPlugin {
* This method returns the english-language name of the format
* this plugin imports, e.g. "OFX"
*
* @return QString Name of the format
*/
- virtual QString formatName(void) const = 0;
+ virtual TQString formatName(void) const = 0;
/**
* This method returns the filename filter suitable for passing to
* KFileDialog::setFilter(), e.g. "*.ofx *.qfx" which describes how
* files of this format are likely to be named in the file system
*
* @return QString Filename filter string
*/
- virtual QString formatFilenameFilter(void) const = 0;
+ virtual TQString formatFilenameFilter(void) const = 0;
/**
* This method returns whether this plugin is able to import
@@ -188,7 +189,7 @@ namespace KMyMoneyPlugin {
*
* @return bool Whether the indicated file is importable by this plugin
*/
- virtual bool isMyFormat( const QString& filename ) const = 0;
+ virtual bool isMyFormat( const TQString& filename ) const = 0;
/**
* Import a file
@@ -197,16 +198,16 @@ namespace KMyMoneyPlugin {
*
* @return bool Whether the import was successful.
*/
- virtual bool import( const QString& filename) = 0;
+ virtual bool import( const TQString& filename) = 0;
/**
* Returns the error result of the last import
*
* @return QString English-language name of the error encountered in the
* last import, or QString() if it was successful.
*
*/
- virtual QString lastError(void) const = 0;
+ virtual TQString lastError(void) const = 0;
};
@@ -167,18 +168,18 @@ namespace KMyMoneyPlugin {
* this plugin imports, e.g. "OFX"
*
- * @return QString Name of the format
+ * @return TQString Name of the format
*/
@@ -167,18 +168,18 @@ namespace KMyMoneyPlugin {
* files of this format are likely to be named in the file system
*
- * @return QString Filename filter string
+ * @return TQString Filename filter string
*/
@@ -197,16 +198,16 @@ namespace KMyMoneyPlugin {
* Returns the error result of the last import
*
- * @return QString English-language name of the error encountered in the
- * last import, or QString() if it was successful.
+ * @return TQString English-language name of the error encountered in the
+ * last import, or TQString() if it was successful.
*
*/